==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/GetSampledRequestsResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.waf.model.primitives.PopulationSize
import scala.jdk.CollectionConverters._
final case class GetSampledRequestsResponse(
    sampledRequests: Option[Iterable[zio.aws.waf.model.SampledHTTPRequest]] =
      None,
    populationSize: Option[PopulationSize] = None,
    timeWindow: Option[zio.aws.waf.model.TimeWindow] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse = {
    import GetSampledRequestsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse
      .builder()
      .optionallyWith(
        sampledRequests.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.sampledRequests)
      .optionallyWith(
        populationSize.map(value =>
          PopulationSize.unwrap(value): java.lang.Long
        )
      )(_.populationSize)
      .optionallyWith(timeWindow.map(value => value.buildAwsValue()))(
        _.timeWindow
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetSampledRequestsResponse.ReadOnly =
    zio.aws.waf.model.GetSampledRequestsResponse.wrap(buildAwsValue())
}
object GetSampledRequestsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetSampledRequestsResponse =
      zio.aws.waf.model.GetSampledRequestsResponse(
        sampledRequests.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        populationSize.map(value => value),
        timeWindow.map(value => value.asEditable)
      )
    def sampledRequests
        : Option[List[zio.aws.waf.model.SampledHTTPRequest.ReadOnly]]
    def populationSize: Option[PopulationSize]
    def timeWindow: Option[zio.aws.waf.model.TimeWindow.ReadOnly]
    def getSampledRequests: ZIO[Any, AwsError, List[
      zio.aws.waf.model.SampledHTTPRequest.ReadOnly
    ]] = AwsError.unwrapOptionField("sampledRequests", sampledRequests)
    def getPopulationSize: ZIO[Any, AwsError, PopulationSize] =
      AwsError.unwrapOptionField("populationSize", populationSize)
    def getTimeWindow
        : ZIO[Any, AwsError, zio.aws.waf.model.TimeWindow.ReadOnly] =
      AwsError.unwrapOptionField("timeWindow", timeWindow)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse
  ) extends zio.aws.waf.model.GetSampledRequestsResponse.ReadOnly {
    override val sampledRequests
        : Option[List[zio.aws.waf.model.SampledHTTPRequest.ReadOnly]] = scala
      .Option(impl.sampledRequests())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.waf.model.SampledHTTPRequest.wrap(item)
        }.toList
      )
    override val populationSize: Option[PopulationSize] = scala
      .Option(impl.populationSize())
      .map(value => zio.aws.waf.model.primitives.PopulationSize(value))
    override val timeWindow: Option[zio.aws.waf.model.TimeWindow.ReadOnly] =
      scala
        .Option(impl.timeWindow())
        .map(value => zio.aws.waf.model.TimeWindow.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse
  ): zio.aws.waf.model.GetSampledRequestsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-waf_2.13-5.17.176.2-sources.jar: zio/aws/waf/model/GetSampledRequestsResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.waf.model.primitives.PopulationSize
import scala.jdk.CollectionConverters._
final case class GetSampledRequestsResponse(
    sampledRequests: Optional[Iterable[zio.aws.waf.model.SampledHTTPRequest]] =
      Optional.Absent,
    populationSize: Optional[PopulationSize] = Optional.Absent,
    timeWindow: Optional[zio.aws.waf.model.TimeWindow] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse = {
    import GetSampledRequestsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse
      .builder()
      .optionallyWith(
        sampledRequests.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.sampledRequests)
      .optionallyWith(
        populationSize.map(value =>
          PopulationSize.unwrap(value): java.lang.Long
        )
      )(_.populationSize)
      .optionallyWith(timeWindow.map(value => value.buildAwsValue()))(
        _.timeWindow
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.GetSampledRequestsResponse.ReadOnly =
    zio.aws.waf.model.GetSampledRequestsResponse.wrap(buildAwsValue())
}
object GetSampledRequestsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.GetSampledRequestsResponse =
      zio.aws.waf.model.GetSampledRequestsResponse(
        sampledRequests.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        populationSize.map(value => value),
        timeWindow.map(value => value.asEditable)
      )
    def sampledRequests
        : Optional[List[zio.aws.waf.model.SampledHTTPRequest.ReadOnly]]
    def populationSize: Optional[PopulationSize]
    def timeWindow: Optional[zio.aws.waf.model.TimeWindow.ReadOnly]
    def getSampledRequests: ZIO[Any, AwsError, List[
      zio.aws.waf.model.SampledHTTPRequest.ReadOnly
    ]] = AwsError.unwrapOptionField("sampledRequests", sampledRequests)
    def getPopulationSize: ZIO[Any, AwsError, PopulationSize] =
      AwsError.unwrapOptionField("populationSize", populationSize)
    def getTimeWindow
        : ZIO[Any, AwsError, zio.aws.waf.model.TimeWindow.ReadOnly] =
      AwsError.unwrapOptionField("timeWindow", timeWindow)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse
  ) extends zio.aws.waf.model.GetSampledRequestsResponse.ReadOnly {
    override val sampledRequests
        : Optional[List[zio.aws.waf.model.SampledHTTPRequest.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sampledRequests())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.waf.model.SampledHTTPRequest.wrap(item)
          }.toList
        )
    override val populationSize: Optional[PopulationSize] =
      zio.aws.core.internal
        .optionalFromNullable(impl.populationSize())
        .map(value => zio.aws.waf.model.primitives.PopulationSize(value))
    override val timeWindow: Optional[zio.aws.waf.model.TimeWindow.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.timeWindow())
        .map(value => zio.aws.waf.model.TimeWindow.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetSampledRequestsResponse
  ): zio.aws.waf.model.GetSampledRequestsResponse.ReadOnly = new Wrapper(impl)
}
